# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2012 Canonical
# Author: Thomi Richards
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.


import json
import logging

from testapp import plugins

__all__ = ('create_application_from_path',
    'create_application_from_file',
    )


logger = logging.getLogger(__name__)


def create_application_from_path(path):
    """Create and return an Application instance, reading settings from path.

    This function raises an IOError if the specified path does not exist, or is
    not readable.

    """

    return create_application_from_file(open(path, 'r'))

def create_application_from_file(file_object):
    """Create and return an Application instance, reading settings from the
    file-like object 'file_object'.

    This function raises AttributeError if the object does not have a 'read()'
    method.

    """
    try:
        data = json.load(file_object)
    except ValueError as e:
        raise RuntimeError(e.message)
    return _parse_json_data(data)


def _parse_json_data(data):
    """Load the json_data 'data', and return the constructed application.

    This function raises RuntimeErrors if the data does not conform to the
    expected format.

    """
    if type(data) is not dict:
        raise RuntimeError("Top-level data structure must be a dictionary, not %r" %
            (type(data).__name__))

    plugin_name = data.get("type", plugins.get_default_plugin_name())
    app_plugin = plugins.get_plugin_by_name(plugin_name)
    app_instance = app_plugin(data)
    app_instance.run()

