# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2012 Canonical
# Author: Thomi Richards
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

import logging

from testapp.plugins.qt import QtPlugin


_plugin_registry = {
    QtPlugin.Name: QtPlugin,
    }

_default_plugin = QtPlugin

logger = logging.getLogger(__name__)


def get_plugin_by_name(name):
    """Return the application type plugin class by name."""
    global _plugin_registry
    plugin = _plugin_registry.get(name, None)
    if not plugin:
        logger.error("No plugin was found with name '%s'", name)

    return plugin



def get_default_plugin_name():
    global _default_plugin
    return _default_plugin.Name


def register_plugin(plugin_class):
    """Register plugin_class. Probably not ever needed, except by tests."""
    global _plugin_registry

    old_plugin = _plugin_registry.get(plugin_class.Name, None)
    if old_plugin:
        logger.warning("Plugin %r is already registered with name '%s'. Overwriting it with %r.",
            old_plugin, plugin_class.Name, plugin_class)

    _plugin_registry[plugin_class.Name] = plugin_class


def unregister_plugin_by_name(name):
    """Unregister a plugin with a given name. Probably not ever needed, except by tests."""
    global _plugin_registry

    if name not in _plugin_registry:
        logger.error("Cannot unregister plugin '%s' since it's not already registered.",
            name)
    else:
        _plugin_registry.pop(name)
